@@ -1,21 +1,21 @@
 /*
-    Copyright 2005-2016 Intel Corporation.  All Rights Reserved.
+    Copyright (c) 2005-2016 Intel Corporation
+
+    Licensed under the Apache License, Version 2.0 (the "License");
+    you may not use this file except in compliance with the License.
+    You may obtain a copy of the License at
+
+        http://www.apache.org/licenses/LICENSE-2.0
+
+    Unless required by applicable law or agreed to in writing, software
+    distributed under the License is distributed on an "AS IS" BASIS,
+    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+    See the License for the specific language governing permissions and
+    limitations under the License.
+
+
 
-    This file is part of Threading Building Blocks. Threading Building Blocks is free software;
-    you can redistribute it and/or modify it under the terms of the GNU General Public License
-    version 2  as  published  by  the  Free Software Foundation.  Threading Building Blocks is
-    distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
-    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-    See  the GNU General Public License for more details.   You should have received a copy of
-    the  GNU General Public License along with Threading Building Blocks; if not, write to the
-    Free Software Foundation, Inc.,  51 Franklin St,  Fifth Floor,  Boston,  MA 02110-1301 USA
 
-    As a special exception,  you may use this file  as part of a free software library without
-    restriction.  Specifically,  if other files instantiate templates  or use macros or inline
-    functions from this file, or you compile this file and link it with other files to produce
-    an executable,  this file does not by itself cause the resulting executable to be covered
-    by the GNU General Public License. This exception does not however invalidate any other
-    reasons why the executable file might be covered by the GNU General Public License.
 */
 
 #ifndef __TBB__flow_graph_indexer_impl_H
@@ -25,7 +25,7 @@
 #error Do not #include this internal file directly; use public TBB headers instead.
 #endif
 
-#include "tbb/internal/_flow_graph_types_impl.h"
+#include "_flow_graph_types_impl.h"
 
 namespace internal {
 
@@ -108,42 +108,38 @@ namespace internal {
         typedef typename receiver<T>::predecessor_list_type predecessor_list_type;
         typedef typename receiver<T>::predecessor_type predecessor_type;
 
-        /*override*/ built_predecessors_type &built_predecessors() { return my_built_predecessors; }
+        built_predecessors_type &built_predecessors() __TBB_override { return my_built_predecessors; }
 
-        /*override*/size_t predecessor_count() {
+        size_t predecessor_count() __TBB_override {
             spin_mutex::scoped_lock l(my_pred_mutex);
             return my_built_predecessors.edge_count();
         }
-        /*override*/void internal_add_built_predecessor(predecessor_type &p) {
+        void internal_add_built_predecessor(predecessor_type &p) __TBB_override {
             spin_mutex::scoped_lock l(my_pred_mutex);
             my_built_predecessors.add_edge(p);
         }
-        /*override*/void internal_delete_built_predecessor(predecessor_type &p) {
+        void internal_delete_built_predecessor(predecessor_type &p) __TBB_override {
             spin_mutex::scoped_lock l(my_pred_mutex);
             my_built_predecessors.delete_edge(p);
         }
-        /*override*/void copy_predecessors( predecessor_list_type &v) {
+        void copy_predecessors( predecessor_list_type &v) __TBB_override {
             spin_mutex::scoped_lock l(my_pred_mutex);
             return my_built_predecessors.copy_edges(v);
         }
-        /*override*/void clear_predecessors() {
-            spin_mutex::scoped_lock l(my_pred_mutex);
-            my_built_predecessors.clear();
-        }
 #endif  /* TBB_PREVIEW_FLOW_GRAPH_FEATURES */
     protected:
         template< typename R, typename B > friend class run_and_put_task;
         template<typename X, typename Y> friend class internal::broadcast_cache;
         template<typename X, typename Y> friend class internal::round_robin_cache;
-        task *try_put_task(const T &v) {
+        task *try_put_task(const T &v) __TBB_override {
             return my_try_put_task(v, my_indexer_ptr);
         }
 
     public:
 #if TBB_PREVIEW_FLOW_GRAPH_FEATURES
-        /*override*/void reset_receiver(reset_flags f) { if(f&rf_clear_edges) my_built_predecessors.clear(); }
+        void reset_receiver(reset_flags f) __TBB_override { if(f&rf_clear_edges) my_built_predecessors.clear(); }
 #else
-        /*override*/void reset_receiver(reset_flags /*f*/) { }
+        void reset_receiver(reset_flags /*f*/) __TBB_override { }
 #endif
 
 #if TBB_PREVIEW_FLOW_GRAPH_FEATURES
@@ -191,7 +187,6 @@ namespace internal {
              blt_succ_cnt, blt_succ_cpy
 #endif
         };
-        enum op_stat {WAIT=0, SUCCEEDED, FAILED};
         typedef indexer_node_base<InputTuple,output_type,StructTypes> class_type;
 
         class indexer_node_base_operation : public aggregated_operation<indexer_node_base_operation> {
@@ -273,19 +268,19 @@ namespace internal {
             my_aggregator.initialize_handler(handler_type(this));
         }
 
-        bool register_successor(successor_type &r) {
+        bool register_successor(successor_type &r) __TBB_override {
             indexer_node_base_operation op_data(r, reg_succ);
             my_aggregator.execute(&op_data);
             return op_data.status == SUCCEEDED;
         }
 
-        bool remove_successor( successor_type &r) {
+        bool remove_successor( successor_type &r) __TBB_override {
             indexer_node_base_operation op_data(r, rem_succ);
             my_aggregator.execute(&op_data);
             return op_data.status == SUCCEEDED;
         }
 
-        task * try_put_task(output_type const *v) {
+        task * try_put_task(output_type const *v) { // not a virtual method in this class
             indexer_node_base_operation op_data(v, try__put_task);
             my_aggregator.execute(&op_data);
             return op_data.bypass_t;
@@ -293,36 +288,36 @@ namespace internal {
 
 #if TBB_PREVIEW_FLOW_GRAPH_FEATURES
 
-        built_successors_type &built_successors() { return my_successors.built_successors(); }
+        built_successors_type &built_successors() __TBB_override { return my_successors.built_successors(); }
 
-        void internal_add_built_successor( successor_type &r) {
+        void internal_add_built_successor( successor_type &r) __TBB_override {
             indexer_node_base_operation op_data(r, add_blt_succ);
             my_aggregator.execute(&op_data);
         }
 
-        void internal_delete_built_successor( successor_type &r) {
+        void internal_delete_built_successor( successor_type &r) __TBB_override {
             indexer_node_base_operation op_data(r, del_blt_succ);
             my_aggregator.execute(&op_data);
         }
 
-        size_t successor_count() {
+        size_t successor_count() __TBB_override {
             indexer_node_base_operation op_data(blt_succ_cnt);
             my_aggregator.execute(&op_data);
             return op_data.cnt_val;
         }
 
-        void copy_successors( successor_list_type &v) {
+        void copy_successors( successor_list_type &v) __TBB_override {
             indexer_node_base_operation op_data(blt_succ_cpy);
             op_data.succv = &v;
             my_aggregator.execute(&op_data);
         }
-        void extract() {
+        void extract() __TBB_override {
             my_successors.built_successors().sender_extract(*this);
             indexer_helper<StructTypes,N>::extract(this->my_inputs);
         }
 #endif /* TBB_PREVIEW_FLOW_GRAPH_FEATURES */
     protected:
-        /*override*/void reset_node(reset_flags f) {
+        void reset_node(reset_flags f) __TBB_override {
             if(f & rf_clear_edges) {
                 my_successors.clear();
                 indexer_helper<StructTypes,N>::reset_inputs(this->my_inputs,f);
